gtkComboBoxEntryNew(show = TRUE)
gtkComboBoxEntryNewWithModel(model, text.column)
gtkComboBoxEntryNewText()
gtkComboBoxEntrySetTextColumn(object, text.column)
gtkComboBoxEntryGetTextColumn(object)
gtkComboBoxEntry(show = TRUE)GtkCellEditable and GtkCellLayout.GtkComboBoxEntry is a widget that allows the user to choose from a
list of valid choices or enter a different value. It is very similar
to a GtkComboBox, but it displays the selected value in an entry to
allow modifying it.
In contrast to a GtkComboBox, the underlying model of a GtkComboBoxEntry
must always have a text column (see gtkComboBoxEntrySetTextColumn),
and the entry will show the content of the text column in the selected row. To
get the text from the entry, use gtkComboBoxGetActiveText.
The changed signal will be emitted while typing into a GtkComboBoxEntry,
as well as when selecting an item from the GtkComboBoxEntry's list. Use
gtkComboBoxGetActive or gtkComboBoxGetActiveIter to discover
whether an item was actually selected from the list.
Connect to the activate signal of the GtkEntry (use gtkBinGetChild) to
detect when the user actually finishes entering text.
The convenience API to construct simple text-only GtkComboBoxes can
also be used with GtkComboBoxEntrys which have been constructed
with gtkComboBoxEntryNewText.gtkComboBoxEntry is the equivalent of gtkComboBoxEntryNew.GtkComboBox