gtkLabelNew(str = NULL, show = TRUE)
gtkLabelSetText(object, str)
gtkLabelSetAttributes(object, attrs)
gtkLabelSetMarkup(object, str)
gtkLabelSetMarkupWithMnemonic(object, str)
gtkLabelSetPattern(object, pattern)
gtkLabelSetJustify(object, jtype)
gtkLabelSetEllipsize(object, mode)
gtkLabelSetWidthChars(object, n.chars)
gtkLabelSetMaxWidthChars(object, n.chars)
gtkLabelGet(object)
gtkLabelParseUline(object, string)
gtkLabelSetLineWrap(object, wrap)
gtkLabelSetLineWrapMode(object, wrap.mode)
gtkLabelGetLayoutOffsets(object)
gtkLabelGetMnemonicKeyval(object)
gtkLabelGetSelectable(object)
gtkLabelGetText(object)
gtkLabelNewWithMnemonic(str = NULL, show = TRUE)
gtkLabelSelectRegion(object, start.offset, end.offset)
gtkLabelSetMnemonicWidget(object, widget)
gtkLabelSetSelectable(object, setting)
gtkLabelSetTextWithMnemonic(object, str)
gtkLabelGetAttributes(object)
gtkLabelGetJustify(object)
gtkLabelGetEllipsize(object)
gtkLabelGetWidthChars(object)
gtkLabelGetMaxWidthChars(object)
gtkLabelGetLabel(object)
gtkLabelGetLayout(object)
gtkLabelGetLineWrap(object)
gtkLabelGetLineWrapMode(object)
gtkLabelGetMnemonicWidget(object)
gtkLabelGetSelectionBounds(object)
gtkLabelGetUseMarkup(object)
gtkLabelGetUseUnderline(object)
gtkLabelGetSingleLineMode(object)
gtkLabelGetAngle(object)
gtkLabelSetLabel(object, str)
gtkLabelSetUseMarkup(object, setting)
gtkLabelSetUseUnderline(object, setting)
gtkLabelSetSingleLineMode(object, single.line.mode)
gtkLabelSetAngle(object, angle)
gtkLabel(str = NULL, show = TRUE)GtkLabel widget displays a small amount of text. As the name
implies, most labels are used to label another widget such as a
GtkButton, a GtkMenuItem, or a GtkOptionMenu."_File", to the
functions gtkLabelNewWithMnemonic or
gtkLabelSetTextWithMnemonic.
Mnemonics automatically activate any activatable widget the label is
inside, such as a GtkButton; if the label is not inside the
mnemonic's target widget, you have to tell the label about the target
using gtkLabelSetMnemonicWidget. Here's a simple example where
the label is inside a button:# Pressing Alt-H will activate this button button <- gtkButton() label <- gtkLabelNewWithMnemonic("_Hello") button$add(label) There's a convenience function to create buttons with a mnemonic label already inside:
# Pressing Alt+H will activate this button button <- gtkButtonNewWithMnemonic("_Hello")
To create a mnemonic for a widget alongside the label, such as a
GtkEntry, you have to point the label at the entry with
gtkLabelSetMnemonicWidget:
# Pressing Alt+H will focus the entry
entry <- gtkEntry();
label <- gtkLabelNewWithMnemonic("_Hello")
label$setMnemonicWidget(entry)
gtkLabelSetMarkup must be valid; for example,
literal >/& characters must be escaped as <,
>, and &. If you pass text obtained from the user, file,
or a network to gtkLabelSetMarkup, you'll want to escape it with
gMarkupEscapeText() or gMarkupPrintfEscaped().
Markup strings are just a convenient way to set the PangoAttrList on
a label; gtkLabelSetAttributes may be a simpler way to set
attributes in some cases. Be careful though; PangoAttrList tends to
cause internationalization problems, unless you're applying attributes
to the entire string (i.e. unless you set the range of each attribute
to [0, G_MAXINT)). The reason is that specifying the start_index and
end_index for a PangoAttribute requires knowledge of the exact string
being displayed, so translations will cause problems.gtkLabelSetSelectable.
Selectable labels allow the user to copy the label contents to
the clipboard. Only labels that contain useful-to-copy information
-- such as error messages -- should be made selectable.gtkLabelSetLineWrap.
gtkLabelSetJustify sets how the lines in a label align
with one another. If you want to set how the label as a whole
aligns in its available space, see gtkMiscSetAlignment.gtkLabel is the result of collapsing the constructors of GtkLabel (gtkLabelNew, gtkLabelNewWithMnemonic) and accepts a subset of its arguments matching the required arguments of one of its delegate constructors.