cairoVersion()
cairoVersionString()Snapshots --------- 1.1.2 - A snapshot (working toward the 1.2.0 release)
In-progress development (eg. from git) -------------------------------------- 1.0.1 - Development on a maintenance branch (toward 1.0.2 release) 1.1.1 - Development on head (toward 1.1.2 snapshot and 1.2.0 release)
Run-time -------- \link{cairoVersionString} Human-readable \link{cairoVersion} Encoded, suitable for comparison For example, checking that the cairo version is greater than or equal to 1.0.0 could be achieved at compile-time or run-time as follows:
# \code{if} \code{CAIRO_VERSION} >= \code{CAIRO_VERSION_ENCODE} (1, 0, 0) printf ("Compiling with suitable cairo version:# \code{endif}
if ( \link{cairoVersion} >= \code{CAIRO_VERSION_ENCODE} (1, 0, 0)) printf ("Running with suitable cairo version: