NULL.cairoCopyClipRectangleList(cr)crCairo] a cairo contextCairoRectangleList] the current clip region as a list of rectangles in user coordinates.CAIRO_STATUS_CLIP_NOT_REPRESENTABLE to
indicate that the clip region cannot be represented as a list of
user-space rectangles. The status may have other values to indicate
other errors. Since 1.4