Learn R Programming

RGtk2 (version 2.10.9-1)

cairoFillExtents: cairoFillExtents

Description

Computes a bounding box in user coordinates covering the area that would be affected by a cairoFill operation given the current path and fill parameters. If the current path is empty, returns an empty rectangle (0,0, 0,0). Surface dimensions and clipping are not taken into account.

Usage

cairoFillExtents(cr)

Arguments

cr
[Cairo] a cairo context

Value

  • A list containing the following elements:
  • x1[numeric] left of the resulting extents
  • y1[numeric] top of the resulting extents
  • x2[numeric] right of the resulting extents
  • y2[numeric] bottom of the resulting extents

Details

See cairoFill, cairoSetFillRule and cairoFillPreserve.