cairoGetDash: cairoGetDash
Description
Gets the current dash list. If not NULL, dashes should be big
enough to hold at least the number of values returned by
cairoGetDashCount.Value
- A list containing the following elements:
offset[numeric] return value for the current dash offset, or NULLdashes[numeric] the dash specification