Learn R Programming

RGtk2 (version 2.10.9-1)

cairoGetGroupTarget: cairoGetGroupTarget

Description

Gets the target surface for the current group as started by the most recent call to cairoPushGroup or cairoPushGroupWithContent.

Usage

cairoGetGroupTarget(cr)

Arguments

cr
[Cairo] a cairo context

Value

Details

This function will return NULL if called "outside" of any group rendering blocks, (that is, after the last balancing call to cairoPopGroup or cairoPopGroupToSource).

Since 1.2