cairoImageSurfaceGetData: cairoImageSurfaceGetData
Description
Get a pointer to the data of the image surface, for direct
inspection or modification.Usage
cairoImageSurfaceGetData(surface)
Value
- [char] a pointer to the image data of this surface or NULL
if
surface is not an image surface.