filename.cairoPdfSurfaceCreate(filename, width.in.points, height.in.points)filenamewidth.in.pointsheight.in.pointsCairoSurface] a pointer to the newly created surface. The caller
owns the surface and should call cairo_surface_destroy when done
with it.This function always returns a valid pointer, but it will return a
pointer to a "nil" surface if an error such as out of memory
occurs. You can use cairoSurfaceStatus to check for this.