Learn R Programming

RGtk2 (version 2.10.9-1)

cairoPopGroupToSource: cairoPopGroupToSource

Description

Terminates the redirection begun by a call to cairoPushGroup or cairoPushGroupWithContent and installs the resulting pattern as the source pattern in the given cairo context.

Usage

cairoPopGroupToSource(cr)

Arguments

cr
[Cairo] a cairo context

Details

The behavior of this function is equivalent to the sequence of operations: cairo_pattern_t *group = cairo_pop_group (cr); cairo_set_source (cr, group); cairo_pattern_destroy (group); but is more convenient as their is no need for a variable to store the short-lived pointer to the pattern. The cairoPopGroup function calls cairoRestore, (balancing a call to cairoSave by the push_group function), so that any changes to the graphics state will not be visible outside the group.

Since 1.2