cairoStroke. A dash pattern
is specified by dashes, a list of positive values. Each value
provides the length of alternate "on" and "off" portions of the
stroke. The offset specifies an offset into the pattern at which
the stroke begins.cairoSetDash(cr, dashes, offset)crCairo] a cairo contextdashesoffsetcairoSetDash.
If num.dashes is 0 dashing is disabled.
If num.dashes is 1 a symmetric pattern is assumed with alternating
on and off portions of the size specified by the single value in
dashes.
If any value in dashes is negative, or if all values are 0, then
cairo.t will be put into an error state with a status of
CAIRO_STATUS_INVALID_DASH.