cairoSurfaceGetDeviceOffset: cairoSurfaceGetDeviceOffset
Usage
cairoSurfaceGetDeviceOffset(surface)
Value
- A list containing the following elements:
x.offset[numeric] the offset in the X direction, in device unitsy.offset[numeric] the offset in the Y direction, in device units