Learn R Programming

RGtk2 (version 2.10.9-1)

custom-tree-models: Custom GtkTreeModel implementations

Description

Functions that allow one to implement a custom GtkTreeModel

Usage

gtkTreeIterGetId(iter)
  gtkTreeIterSetId(iter, id)

Arguments

iter
The GtkTreeIter of a custom model
id
The integer code identifying iter

Value

  • For gtkTreeIterGetId, the integer code identifying iter

Details

These functions allow one to associate integer codes with the GtkTreeIter structures passed to the GtkTreeModel virtuals.

See Also

gClass