gdkPixbufSavev: gdkPixbufSavev
Description
Saves pixbuf to a file in type, which is currently "jpeg", "png", "tiff", "ico" or "bmp".
If error is set, FALSE will be returned.
See gdkPixbufSave for more details.Usage
gdkPixbufSavev(object, filename, type, option.keys, option.values, .errwarn = TRUE)
Arguments
filename
[char] name of file to save.
type
[char] name of file format.
option.keys
[char] name of options to set, NULL-terminated
option.values
[char] values for named options
.errwarn
Whether to issue a warning on error or fail silently
Value
- A list containing the following elements:
- retval[logical] whether an error was set
type[char] name of file format.option.keys[char] name of options to set, NULL-terminatedoption.values[char] values for named optionserror[GError] return location for error, or NULL- .errwarnWhether to issue a warning on error or fail silently