Learn R Programming

RGtk2 (version 2.12.13)

GtkLinkButton: GtkLinkButton

Description

Create buttons bound to a URL

Arguments

Methods and Functions

gtkLinkButtonNew(uri) gtkLinkButtonNewWithLabel(uri, label = NULL, show = TRUE) gtkLinkButtonGetUri(object) gtkLinkButtonSetUri(object, uri) gtkLinkButtonSetUriHook(func, data) gtkLinkButton(uri, label = NULL, show = TRUE)

Hierarchy

\link{GObject} +----GInitiallyUnowned +----\link{GtkObject} +----\link{GtkWidget} +----\link{GtkContainer} +----\link{GtkBin} +----\link{GtkButton} +----GtkLinkButton

Interfaces

GtkLinkButton implements AtkImplementorIface and GtkBuildable.

Detailed Description

A GtkLinkButton is a GtkButton with a hyperlink, similar to the one used by web browsers, which triggers an action when clicked. It is useful to show quick links to resources. A link button is created by calling either gtkLinkButtonNew or gtkLinkButtonNewWithLabel. If using the former, the URI you pass to the constructor is used as a label for the widget. The URI bound to a GtkLinkButton can be set specifically using gtkLinkButtonSetUri, and retrieved using gtkLinkButtonGetUri. GtkLinkButton offers a global hook, which is called when the used clicks on it: see gtkLinkButtonSetUriHook. GtkLinkButton was added in GTK+ 2.10.

Convenient Construction

gtkLinkButton is the equivalent of gtkLinkButtonNewWithLabel.

References

http://developer.gnome.org/doc/API/2.0/gtk/GtkLinkButton.html

See Also

GtkButton