gdkRgbXpixelFromRgb: gdkRgbXpixelFromRgb
Description
Finds the X pixel closest in color to the rgb color specified. This
value may be used to set the pixel field of
a GdkColor struct.
WARNING: gdk_rgb_xpixel_from_rgb is deprecated and should not be used in newly-written code.Usage
gdkRgbXpixelFromRgb(rgb)
Value
[numeric] The X pixel value.